#
# Makefile Template for Tessy
# Compiler: Green Hills MPC
# Debugger: LAUTERBACH TRACE32
# Template Version: 2
#

# Defines to be generated by Tessy:
#
# BUFFER_SIZE           :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# CPU                   :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# ENDIANESS             :=
# EXEFILE_EXTENSION     :=
# LINKER_FILE           :=
# MODULE_PATH           :=
# MODULE_PATH_DOS       :=
# OBJFILE_EXTENSION     :=
# PROJECTROOT           :=
# TARGET_INSTALL_PATH   :=
# TESSY_BIN             :=
# TESSY_SYS             :=
# TESTOBJECT            :=
# TIMER_FILE            :=
# TARGET_INSTALL_PATH   :=
# TIMER_FILE            :=
# USER_LINK_OPTIONS     :=

#####################################################################
#BEGIN_DEFINES
#####################################################################

#
# Special macros for includes and defines
#
TS_DEF_SEPARATOR :=-D
define TS_DEFINE
$(subst ;, $(TS_DEF_SEPARATOR),$(1))
endef

TS_INC_SEPARATOR :=-I
define TS_INCLUDE
$(subst ;, $(TS_INC_SEPARATOR),$(1))
endef


TESSY_SYS_DOS    := $(shell ts_pathname -s $(TESSY_SYS))
GHSPPC_HOME      := $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)')

ifneq ($(InitSrcDir),)
INITOBJDIR       := $(shell ts_pathname -s $(InitObjDir))
INITSRCDIR       := $(shell ts_pathname -s $(InitSrcDir))
endif

TS_NAME          := TS_TRACE32
IDE_NAME         := trace32
COMPANY_NAME     := ghs
PROCESSOR_NAME   := mpc

ifeq ("little","$(ENDIANESS)")
  TS_BYTEORDER := TS_HOST_BYTEORDER
  TS_BYTEORDER_OPTION :=-littleendian
endif
ifeq ("big","$(ENDIANESS)")
  TS_BYTEORDER := TS_NET_BYTEORDER
  TS_BYTEORDER_OPTION :=-bigendian
endif
ifndef TS_BYTEORDER
  $(error Attribute 'Endianess' has invalid value '$(ENDIANESS)', only 'little' and 'big' are allowed.)
endif

all	 : master slave
master : $(MODULE_PATH)/ts_$(TESTOBJECT)_m.exe
slave  : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION)

#
# MASTER & COMM Makefiles
# (you should not need to modify these settings)
#
M_COMM_MAKE		:=	$(TESSY_SYS)/make/master_$(IDE_NAME)_gnu_i386.mk
S_COMM_MAKE		:=	$(TESSY_SYS)/src/comm/comm_$(IDE_NAME)_$(COMPANY_NAME)_$(PROCESSOR_NAME).mk


#
# SLAVE
# (You may change these settings to use your own compiler/linker options)
#
# CPU mpc560,560xP
S_COMP_OPTIONS  := -DTESSY -DTS_SLAVE -DTS_TRACE32 -DTS_HAVE_FLOAT64 -DTS_HAVE_INT64 -DTS_DOUBLE_SWAP_DWORDS \
                   -g -c -MD -bsp generic -cpu=$(CPU) $(TS_BYTEORDER_OPTION) -ansi -object_dir=$(MODULE_PATH_DOS) -filetype.c
S_LINK_OPTIONS  := -g -language=c $(LINKER_FILE) $(TS_BYTEORDER_OPTION) -ansi -MD -bsp generic -cpu=$(CPU) \
                  -object_dir=$(MODULE_PATH_DOS)
S_INCLUDES		:= -I$(TESSY_SYS_DOS)\include\tessy\comm -I$(MODULE_PATH_DOS)

S_CC           := $(GHSPPC_HOME)\ccppc.exe
S_LINK         := $(GHSPPC_HOME)\ccppc.exe
S_STUB_OBJECT  := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs$(OBJFILE_EXTENSION)
S_UC_OBJECT    := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr$(OBJFILE_EXTENSION)

#####################################################################
#END_DEFINES
#####################################################################

#####################################################################
#BEGIN_SOURCE
#####################################################################

#
# Template rules
#
$(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER)$(OBJFILE_EXTENSION): $(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER).c
	$(S_CC) $(S_INCLUDES) $(call TS_INCLUDE,$(USER_INCLUDES$$(SOURCENUMBER))) $(S_COMP_OPTIONS) \
		$(call TS_DEFINE,$(USER_DEFINES$$(SOURCENUMBER))$(S_COM_OPTIONS)) \
		$(USER_COMP_OPTIONS$$(SOURCENUMBER)) "$<" -o $@


#####################################################################
#END_SOURCE
#####################################################################

#####################################################################
#BEGIN_TARGETS
#####################################################################


# COMPILE USERCODE / STUBS
#
$(S_UC_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.c
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) $< -o $@

$(S_STUB_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.c
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) $< -o $@


#
# COMPILE/LINK MASTER
#

include $(M_COMM_MAKE)


#
# COMPILE SLAVE COMMUNICATION MODULES

include $(S_COMM_MAKE)


#
# COMPILE/LINK SLAVE
#
$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.c
	@echo *
	@echo ***** Compiling Slave *****
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) $< -o $@


$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
															$(S_SRC_OBJECTS) \
															$(S_UC_OBJECT) \
															$(S_STUB_OBJECT) \
															$(S_C1_OBJECTS) \
															$(S_OBJECTS)
	@echo *
	@echo ***** Linking Slave *****
	$(S_LINK) $(S_LINK_OPTIONS) $(USER_LINK_OPTIONS) $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
             $(S_SRC_OBJECTS) $(S_UC_OBJECT) $(S_STUB_OBJECT) $(S_C1_OBJECTS) \
             $(S_OBJECTS) -o "$@"
	@-ts_rm "$(MODULE_PATH)"/*$(OBJFILE_EXTENSION)


#####################################################################
#END_TARGETS
#####################################################################
